@@ -16,13 +16,15 @@ dbp <- function(x1, x2 = NULL, lambda, logged = TRUE) {
   mm <- max( max1, max2 )   ;   mn <- min(max1, max2)
   omn <- 0:mn
   fac <- factorial( omn )
-  ch <- matrix(numeric( (mm + 1)^2 ), nrow = mm + 1, ncol = mm + 1 )
+  #ch <- matrix(numeric( (mm + 1)^2 ), nrow = mm + 1, ncol = mm + 1 )
+  #for ( i in 1:c(mm + 1) ) {
+  #  for ( j in c(i - 1):c(mm + 1) ) {
+  #    ch[i, j] <- choose(j, i - 1)
+  #  }
+  #}
+  i <- j <- 1:c(mm + 1)
+  ch <- choose( Rfast::rep_row(j, mm + 1), i - 1 )
   rownames(ch) <- colnames(ch) <- 0:mm
-  for ( i in 1:c(mm + 1) ) {
-    for ( j in c(i - 1):c(mm + 1) ) {
-      ch[i, j] <- choose(j, i - 1)
-    }
-  }
   ly1 <- lgamma(x1 + 1)
   ly2 <- lgamma(x2 + 1)
 
@@ -33,9 +35,8 @@ dbp <- function(x1, x2 = NULL, lambda, logged = TRUE) {
   l2 <- log(m2 - l3)
   for (j in 1:n) {
     f1[j] <- x1[j] * l1 - ly1[j] + x2[j] * l2 - ly2[j]
-    f2[j] <- log( sum( ch[ 1:c(ind[j] + 1), x1[j] ] *
-                       ch[ 1:c(ind[j] + 1), x2[j] ] * fac[1:c(ind[j] + 1)] *
-                       expo[ 1:c(ind[j] + 1) ] ) )
+    f2[j] <- log( sum( ch[ 1:c(ind[j] + 1), x1[j] ] * ch[ 1:c(ind[j] + 1), x2[j] ] *
+                       fac[ 1:c(ind[j] + 1) ] * expo[ 1:c(ind[j] + 1) ] ) )
   }
 
   ep <- which( is.infinite(f2) )
